@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
 """
-@author: Philipp Temminghoff
 """
 
 import pathlib
@@ -9,9 +8,8 @@ from qtpy import QtCore
 
 
 class Dir(QtCore.QDir):
-
     def __str__(self):
         return self.absolutePath()
 
-    def to_path(self):
+    def to_path(self) -> pathlib.Path:
         return pathlib.Path(self.absolutePath())
