@@ -1,21 +1,24 @@
 # -*- coding: utf-8 -*-
 """
-@author: Philipp Temminghoff
 """
 
+import collections
 from contextlib import contextmanager
+import itertools
 
 from qtpy import QtCore
 
 
-class Object(QtCore.QObject):
+counter_dict = collections.defaultdict(itertools.count)
 
+
+class Object(QtCore.QObject):
     def __getstate__(self):
         return dict(object_name=self.objectName())
 
     def __setstate__(self, state):
         self.__init__()
-        self.id = state["object_name"]
+        self.set_id(state["object_name"])
 
     @contextmanager
     def block_signals(self):
@@ -30,9 +33,17 @@ class Object(QtCore.QObject):
                 dct[k] = v.to_json()
         return dct
 
-    def set_object_name(self, name: str):
+    def set_unique_id(self):
+        class_name = type(self).__name__
+        count = next(counter_dict[class_name])
+        self.set_id(f"{class_name}_{count}")
+
+    def set_id(self, name: str):
         self.setObjectName(name)
 
+    def get_id(self):
+        return self.objectName()
+
     @property
     def id(self) -> str:
         return self.objectName()
