@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
 """
-@author: Philipp Temminghoff
 """
 
 from qtpy import QtCore
@@ -13,4 +12,4 @@ QtCore.QSortFilterProxyModel.__bases__ = (core.AbstractProxyModel,)
 
 class SortFilterProxyModel(QtCore.QSortFilterProxyModel):
 
-    HEADER = []
+    HEADER: list = []
