@@ -1,13 +1,11 @@
 # -*- coding: utf-8 -*-
 """
-@author: Philipp Temminghoff
 """
 
 from prettyqt import gui
 
 
 class CompositeValidator(gui.Validator):
-
     def __repr__(self):
         return f"CompositeValidator({self.validators})"
 
@@ -22,14 +20,14 @@ class CompositeValidator(gui.Validator):
         self.__init__()
         self.validators = state.get("validators", [])
 
-    def validate(self, text, pos=0):
+    def validate(self, text: str, pos: int = 0) -> tuple:
         vals = [v.validate(text, pos)[0] for v in self.validators]
         return (min(vals), text, pos)
 
 
 if __name__ == "__main__":
-    from prettyqt import widgets
-    from prettyqt import custom_validators
+    from prettyqt import custom_validators, widgets
+
     val1 = custom_validators.NotEmptyValidator()
     val2 = custom_validators.PathValidator()
     val = CompositeValidator([val1, val2])
