@@ -1,16 +1,15 @@
 # -*- coding: utf-8 -*-
 """
-@author: Philipp Temminghoff
 """
 
-import regex as re
 import sre_constants
 
+import regex as re
+
 from prettyqt import gui
 
 
 class RegexPatternValidator(gui.Validator):
-
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.error_message = ""
@@ -19,7 +18,7 @@ class RegexPatternValidator(gui.Validator):
     def __repr__(self):
         return "RegexPatternValidator()"
 
-    def validate(self, text, pos=0):
+    def validate(self, text: str, pos: int = 0) -> tuple:
         # if text == "":
         #     self.compiled = None
         #     return (self.Intermediate, text, pos)
@@ -40,6 +39,7 @@ class RegexPatternValidator(gui.Validator):
 
 if __name__ == "__main__":
     from prettyqt import widgets
+
     app = widgets.app()
     w = widgets.LineEdit()
     val = RegexPatternValidator()
