@@ -1,13 +1,11 @@
 # -*- coding: utf-8 -*-
 """
-@author: Philipp Temminghoff
 """
 
 from prettyqt import widgets
 
 
 class BoolDictToolButton(widgets.ToolButton):
-
     def __init__(self, title, icon=None, dct=None, parent=None):
         super().__init__(parent=parent)
         self.set_text(title)
@@ -31,7 +29,7 @@ class BoolDictToolButton(widgets.ToolButton):
             action = widgets.Action()
             action.set_text(v)
             action.setCheckable(True)
-            action.id = k
+            action.set_id(k)
             menu.add(action)
 
     def as_dict(self):
@@ -40,8 +38,7 @@ class BoolDictToolButton(widgets.ToolButton):
 
 if __name__ == "__main__":
     app = widgets.app()
-    dct = dict(a="test",
-               b="test2")
+    dct = dict(a="test", b="test2")
     w = BoolDictToolButton("Title", None, dct)
     w.show()
     app.exec_()
