@@ -1,10 +1,9 @@
 # -*- coding: utf-8 -*-
 """
-@author: Philipp Temminghoff
 """
 
 import pathlib
-from typing import Optional
+from typing import Optional, Union
 
 from prettyqt import core, widgets
 
@@ -13,17 +12,23 @@ class FileChooserButton(widgets.Widget):
 
     value_changed = core.Signal(pathlib.Path)
 
-    def __init__(self, extensions=None, mode="save", file_mode="existing_files",
-                 root=None, parent=None):
+    def __init__(
+        self,
+        extensions=None,
+        mode="save",
+        file_mode="existing_files",
+        root=None,
+        parent=None,
+    ):
         """initialize FileChooserButton
 
         Args:
-            extensions: dict allowed extensions (default: {None})
+            extensions: dict allowed extensions
                         form: "'name': ['.ext1', '.ext2']"
-            mode: Accept mode ("save" or "load") (default: {"save"})
+            mode: Accept mode ("save" or "load")
             file_mode: File mode ("existing_files", "existing_file", "any_file",
-                                  or "directory") (default: {"existing_files"})
-            parent: parent widget (default: {None})
+                                  or "directory")
+            parent: parent widget
         """
         super().__init__(parent)
         self.path = None
@@ -48,9 +53,7 @@ class FileChooserButton(widgets.Widget):
         layout += self.button
 
     def __getstate__(self):
-        return dict(path=self.path,
-                    extensions=self.extensions,
-                    enabled=self.isEnabled())
+        return dict(path=self.path, extensions=self.extensions, enabled=self.isEnabled())
 
     def __setstate__(self, state):
         self.__init__(state["extensions"])
@@ -59,11 +62,13 @@ class FileChooserButton(widgets.Widget):
 
     @core.Slot()
     def open_file(self):
-        dialog = widgets.FileDialog(parent=self,
-                                    path_id="file_path",
-                                    mode=self.mode,
-                                    path=self.root,
-                                    file_mode=self.file_mode)
+        dialog = widgets.FileDialog(
+            parent=self,
+            path_id="file_path",
+            mode=self.mode,
+            path=self.root,
+            file_mode=self.file_mode,
+        )
         if self.extensions:
             dialog.set_extension_filter(self.extensions)
         if not dialog.choose():
@@ -71,7 +76,7 @@ class FileChooserButton(widgets.Widget):
         self.set_path(dialog.selected_file())
         self.value_changed.emit(self.path)
 
-    def set_path(self, path):
+    def set_path(self, path: Union[str, pathlib.Path]):
         self.path = path
         self.lineedit.set_text(str(path))
 
