@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
 """
-@author: Philipp Temminghoff
 """
 
 from typing import Callable, Optional, Union
@@ -10,12 +9,11 @@ from prettyqt.utils import icons
 
 
 class SidebarWidget(widgets.MainWindow):
-
     def __init__(self, parent=None):
         super().__init__(parent=None)
         self.sidebar = widgets.ToolBar()
-        self.sidebar.id = "SidebarWidget"
-        self.sidebar.title = "Sidebar"
+        self.sidebar.set_id("SidebarWidget")
+        self.sidebar.set_title("Sidebar")
         self.sidebar.set_style("text_below_icon")
         self.sidebar.setFloatable(False)
         self.sidebar.set_allowed_areas("all")
@@ -31,13 +29,15 @@ class SidebarWidget(widgets.MainWindow):
         w.set_layout(main_layout)
         self.setCentralWidget(w)
 
-    def add_tab(self,
-                item,
-                title: str,
-                icon: icons.IconType = None,
-                show: bool = False,
-                shortcut: Optional[str] = None,
-                area: str = "top"):
+    def add_tab(
+        self,
+        item,
+        title: str,
+        icon: icons.IconType = None,
+        show: bool = False,
+        shortcut: Optional[str] = None,
+        area: str = "top",
+    ):
         page = item
         self.area.box.add(page)
         # button = widgets.ToolButton()
@@ -49,18 +49,16 @@ class SidebarWidget(widgets.MainWindow):
         # self.sidebar.addWidget(button)
         # self.sidebar.add_separator()
         if area == "top":
-            act = widgets.Action(text=title,
-                                 icon=icon,
-                                 shortcut=shortcut,
-                                 parent=self.sidebar)
+            act = widgets.Action(
+                text=title, icon=icon, shortcut=shortcut, parent=self.sidebar
+            )
             act.setCheckable(True)
             act.triggered.connect(lambda: self.set_tab(page))
             self.sidebar.insertAction(self.spacer_action, act)
         else:
-            act = self.sidebar.add_action(title,
-                                          icon,
-                                          lambda: self.set_tab(page),
-                                          checkable=True)
+            act = self.sidebar.add_action(
+                title, icon, lambda: self.set_tab(page), checkable=True
+            )
         button = self.sidebar.widgetForAction(act)
         if len(self.area.box) == 1:
             button.setChecked(True)
@@ -92,20 +90,20 @@ class SidebarWidget(widgets.MainWindow):
         else:
             self.sidebar.add_separator(text)
 
-    def add_action(self,
-                   title: str,
-                   icon: icons.IconType = None,
-                   callback: Callable = None,
-                   checkable: bool = False,
-                   shortcut: Optional[str] = None,
-                   area: str = "top"):
+    def add_action(
+        self,
+        title: str,
+        icon: icons.IconType = None,
+        callback: Callable = None,
+        checkable: bool = False,
+        shortcut: Optional[str] = None,
+        area: str = "top",
+    ):
         # act = self.sidebar.add_action(label=title,
         #                                      icon=icon,
         #                                      callback=callback,
         #                                      checkable=checkable)
-        act = widgets.Action(text=title,
-                             icon=icon,
-                             shortcut=shortcut)
+        act = widgets.Action(text=title, icon=icon, shortcut=shortcut)
         act.setCheckable(checkable)
         if callback:
             act.triggered.connect(callback)
@@ -116,7 +114,7 @@ class SidebarWidget(widgets.MainWindow):
         return act
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     app = widgets.app()
     ex = SidebarWidget()
     page_1 = widgets.PlainTextEdit()
