@@ -1,13 +1,11 @@
 # -*- coding: utf-8 -*-
 """
-@author: Philipp Temminghoff
 """
 
 from qtpy import QtGui
 
 
 class Color(QtGui.QColor):
-
     def __repr__(self):
         return f"Color({self.red()}, {self.green()}, {self.blue()}, {self.alpha()})"
 
@@ -42,5 +40,5 @@ class Color(QtGui.QColor):
     def from_cmyk(cls, *args, **kwargs):
         return cls(cls.fromCmykF(*args, **kwargs))
 
-    def as_qt(self):
-        return QtGui.QColor(*self.getRgb())
+    def as_qt(self) -> QtGui.QColor:
+        return QtGui.QColor(self)
