@@ -1,22 +1,22 @@
 # -*- coding: utf-8 -*-
 """
-@author: Philipp Temminghoff
 """
 
-from qtpy import QtGui, QtCore
+from qtpy import QtCore, QtGui
 
 from prettyqt.utils import bidict
 
 
-SHAPES = bidict(arrow=QtCore.Qt.ArrowCursor,
-                uparrow=QtCore.Qt.UpArrowCursor,
-                cross=QtCore.Qt.CrossCursor,
-                wait=QtCore.Qt.WaitCursor,
-                caret=QtCore.Qt.IBeamCursor)
+SHAPES = bidict(
+    arrow=QtCore.Qt.ArrowCursor,
+    uparrow=QtCore.Qt.UpArrowCursor,
+    cross=QtCore.Qt.CrossCursor,
+    wait=QtCore.Qt.WaitCursor,
+    caret=QtCore.Qt.IBeamCursor,
+)
 
 
 class Cursor(QtGui.QCursor):
-
     def set_shape(self, shape: str):
         """sets cursor shape
 
