@@ -1,18 +1,17 @@
 # -*- coding: utf-8 -*-
 """
-@author: Philipp Temminghoff
 """
 
 import pathlib
 
+
 import qtawesome as qta
 from qtpy import QtCore, QtGui
 
-from prettyqt import gui
+from prettyqt import core, gui
 
 
 class Icon(QtGui.QIcon):
-
     def __init__(self, icon=None):
         if isinstance(icon, pathlib.Path):
             icon = str(icon)
@@ -40,23 +39,28 @@ class Icon(QtGui.QIcon):
         stream >> px
         super().__init__(px)
 
-    @staticmethod
-    def by_name(name):
-        return qta.icon(name)
+    @classmethod
+    def by_name(cls, name: str) -> "Icon":
+        return cls(qta.icon(name))
 
     @classmethod
-    def for_color(cls, color_str: str):
+    def for_color(cls, color_str: str) -> "Icon":
         color = gui.Color.from_text(color_str)
         if color.isValid():
             bitmap = gui.Pixmap(16, 16)
             bitmap.fill(color)
             icon = gui.Icon(bitmap)
         else:
-            icon = qta.icon("mdi.card-outline")
+            icon = cls(qta.icon("mdi.card-outline"))
         return icon
 
+    def get_pixmap(self, size: int) -> QtGui.QPixmap:
+        size = core.Size(size, size)
+        return self.pixmap(size)
+
 
 if __name__ == "__main__":
     from prettyqt import widgets
+
     app = widgets.app()
     icon = Icon.for_color("green")
