@@ -1,13 +1,11 @@
 # -*- coding: utf-8 -*-
 """
-@author: Philipp Temminghoff
 """
 
 from prettyqt import core, gui
 
 
 class RegularExpressionValidator(gui.Validator):
-
     def __init__(self, regex=None):
         super().__init__()
         self.regex = None
@@ -29,13 +27,13 @@ class RegularExpressionValidator(gui.Validator):
     def regularExpression(self):
         return self.regex
 
-    def set_regex(self, regex: str, flags=0):
+    def set_regex(self, regex: str, flags: int = 0):
         self.regex = core.RegularExpression(regex, flags)
 
     def get_regex(self) -> str:
         return self.regex.pattern()
 
-    def validate(self, text, pos=0):
+    def validate(self, text: str, pos: int = 0) -> tuple:
         if text == "":
             return (self.Intermediate, text, pos)
         match = self.regex.match(text, match_type="prefer_first")
@@ -48,6 +46,7 @@ class RegularExpressionValidator(gui.Validator):
 
 if __name__ == "__main__":
     from prettyqt import widgets
+
     app = widgets.app()
     w = widgets.LineEdit()
     val = RegularExpressionValidator()
