@@ -1,25 +1,25 @@
 # -*- coding: utf-8 -*-
 """
-@author: Philipp Temminghoff
 """
 
-from qtpy import QtGui, QtCore
+from qtpy import QtCore, QtGui
 
-from prettyqt import gui, core
+from prettyqt import core, gui
 from prettyqt.utils import icons
 
 
 class StandardItem(QtGui.QStandardItem):
-
     def __repr__(self):
         return f"StandardItem({self.icon()}, {self.text()!r})"
 
     def __getstate__(self):
-        return dict(text=self.text(),
-                    tooltip=self.toolTip(),
-                    statustip=self.statusTip(),
-                    icon=gui.Icon(self.icon()) if not self.icon().isNull() else None,
-                    data=self.data())
+        return dict(
+            text=self.text(),
+            tooltip=self.toolTip(),
+            statustip=self.statusTip(),
+            icon=gui.Icon(self.icon()) if not self.icon().isNull() else None,
+            data=self.data(),
+        )
 
     def __setstate__(self, state):
         self.__init__()
