@@ -1,24 +1,25 @@
 # -*- coding: utf-8 -*-
 """
-@author: Philipp Temminghoff
 """
 
 from qtpy import QtCore, QtGui
 
 from prettyqt import core, gui
 
+
 QtGui.QStandardItemModel.__bases__ = (core.AbstractItemModel,)
 
-MATCH_FLAGS = dict(exact=QtCore.Qt.MatchExactly,
-                   contains=QtCore.Qt.MatchContains,
-                   starts_with=QtCore.Qt.MatchStartsWith,
-                   ends_with=QtCore.Qt.MatchEndsWith,
-                   wildcard=QtCore.Qt.MatchWildcard,
-                   regex=QtCore.Qt.MatchRegExp)
+MATCH_FLAGS = dict(
+    exact=QtCore.Qt.MatchExactly,
+    contains=QtCore.Qt.MatchContains,
+    starts_with=QtCore.Qt.MatchStartsWith,
+    ends_with=QtCore.Qt.MatchEndsWith,
+    wildcard=QtCore.Qt.MatchWildcard,
+    regex=QtCore.Qt.MatchRegExp,
+)
 
 
 class StandardItemModel(QtGui.QStandardItemModel):
-
     def __getitem__(self, index):
         return self.item(index)
 
@@ -39,7 +40,7 @@ class StandardItemModel(QtGui.QStandardItemModel):
             return self
         raise TypeError("wrong type for addition")
 
-    def get_children(self):
+    def get_children(self) -> list:
         return [self.item(index) for index in range(self.rowCount())]
 
     def add(self, *item):
@@ -56,7 +57,9 @@ class StandardItemModel(QtGui.QStandardItemModel):
 
 if __name__ == "__main__":
     import pickle
+
     from prettyqt import widgets
+
     model = gui.StandardItemModel()
     model.add("test")
     app = widgets.app()
