@@ -1,24 +1,26 @@
 # -*- coding: utf-8 -*-
 """
-@author: Philipp Temminghoff
 """
 # see https://github.com/ITVRoC/SeekurJr/blob/master/seekur_12.04/packages/
 # multimaster_fkie/node_manager_fkie/src/node_manager_fkie/yaml_highlighter.py
 
 from dataclasses import dataclass
+from typing import List, Optional, Union
+
 import regex as re
+
 from prettyqt import gui
 
 
 @dataclass
 class HighlightRule(object):
-    regex = ""
-    color = "black"
-    italic = False
-    bold = False
-    minimal = False
-    font_size = None
-    nth = 0
+    regex: Union[str, List[str]] = ""
+    color: str = "black"
+    italic: bool = False
+    bold: bool = False
+    minimal: bool = False
+    font_size: Optional[float] = None
+    nth: int = 0
 
     def __init_subclass__(cls, **kwargs):
         super().__init_subclass__(**kwargs)
