@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
 """
-@author: Philipp Temminghoff
 """
 
 import regex as re
@@ -24,14 +23,13 @@ VALUE_FORMAT.set_foreground_color("darkgreen")
 
 
 class JsonHighlighter(gui.SyntaxHighlighter):
-
-    def highlightBlock(self, text):
+    def highlightBlock(self, text: str):
         """ Highlight a block of code using the rules outlined in the Constructor
         """
         for m in BRACKETS.finditer(text):
             self.setFormat(m.span()[0], m.span()[1] - m.span()[0], SYMBOL_FORMAT)
 
-        text.replace("\\\"", "  ")
+        text.replace('\\"', "  ")
         for m in REGEXP1.finditer(text):
             self.setFormat(m.span()[0], m.span()[1] - m.span()[0], NAME_FORMAT)
         for m in REGEXP2.finditer(text):
@@ -40,6 +38,7 @@ class JsonHighlighter(gui.SyntaxHighlighter):
 
 if __name__ == "__main__":
     from prettyqt import widgets
+
     app = widgets.app()
     editor = widgets.PlainTextEdit()
     highlighter = JsonHighlighter(editor.document())
