@@ -1,16 +1,17 @@
 # -*- coding: utf-8 -*-
 """
-@author: Philipp Temminghoff
 
 for full list, see:
 - https://cdn.materialdesignicons.com/3.0.39/
 """
 
-from typing import Union
 import pathlib
+from typing import Union
+
 
 import qtawesome as qta
 from qtpy import QtGui
+
 from prettyqt import gui
 
 
@@ -22,7 +23,7 @@ def get_icon(icon: IconType, color: str = "black"):
         icon = gui.Icon()
     elif isinstance(icon, str):
         if icon.startswith("mdi."):
-            icon = qta.icon(icon, color=color)
+            icon = gui.Icon(qta.icon(icon, color=color))
         else:
             icon = gui.Icon(icon)
     elif isinstance(icon, pathlib.Path):
