@@ -109,94 +109,96 @@ def app():
     return Application([])
 
 
-__all__ = ["app",
-           "Application",
-           "AbstractSlider",
-           "AbstractButton",
-           "AbstractSpinBox",
-           "AbstractScrollArea",
-           "AbstractItemView",
-           "MdiSubWindow",
-           "MdiArea",
-           "ScrollBar",
-           "ScrollArea",
-           "Widget",
-           "DesktopWidget",
-           "GraphicsItem",
-           "Style",
-           "StyleOption",
-           "SpacerItem",
-           "SizePolicy",
-           "StylePainter",
-           "BaseDialog",
-           "Dialog",
-           "MessageBox",
-           "ErrorMessage",
-           "FileSystemModel",
-           "LayoutItem",
-           "Layout",
-           "FormLayout",
-           "BoxLayout",
-           "StackedLayout",
-           "GridLayout",
-           "ToolBox",
-           "Slider",
-           "StyleOptionSlider",
-           "StyleOptionFrame",
-           "Frame",
-           "ListWidgetItem",
-           "TreeWidgetItem",
-           "Action",
-           "WidgetAction",
-           "ToolButton",
-           "ToolTip",
-           "Menu",
-           "MenuBar",
-           "StatusBar",
-           "TabWidget",
-           "TabBar",
-           "ToolBar",
-           "HeaderView",
-           "DockWidget",
-           "Label",
-           "PushButton",
-           "CommandLinkButton",
-           "RadioButton",
-           "ComboBox",
-           "SpinBox",
-           "DoubleSpinBox",
-           "CheckBox",
-           "LineEdit",
-           "KeySequenceEdit",
-           "TextEdit",
-           "DateEdit",
-           "TimeEdit",
-           "DateTimeEdit",
-           "CalendarWidget",
-           "PlainTextEdit",
-           "TextBrowser",
-           "ProgressBar",
-           "ColumnView",
-           "ListView",
-           "ListWidget",
-           "TreeView",
-           "TreeWidget",
-           "TableView",
-           "TableWidgetItem",
-           "TableWidget",
-           "SplashScreen",
-           "ProgressDialog",
-           "FontDialog",
-           "FileDialog",
-           "ColorDialog",
-           "InputDialog",
-           "DialogButtonBox",
-           "ButtonGroup",
-           "GroupBox",
-           "Splitter",
-           "Wizard",
-           "WizardPage",
-           "MainWindow",
-           "AbstractItemDelegate",
-           "ItemDelegate",
-           "StyledItemDelegate"]
+__all__ = [
+    "app",
+    "Application",
+    "AbstractSlider",
+    "AbstractButton",
+    "AbstractSpinBox",
+    "AbstractScrollArea",
+    "AbstractItemView",
+    "MdiSubWindow",
+    "MdiArea",
+    "ScrollBar",
+    "ScrollArea",
+    "Widget",
+    "DesktopWidget",
+    "GraphicsItem",
+    "Style",
+    "StyleOption",
+    "SpacerItem",
+    "SizePolicy",
+    "StylePainter",
+    "BaseDialog",
+    "Dialog",
+    "MessageBox",
+    "ErrorMessage",
+    "FileSystemModel",
+    "LayoutItem",
+    "Layout",
+    "FormLayout",
+    "BoxLayout",
+    "StackedLayout",
+    "GridLayout",
+    "ToolBox",
+    "Slider",
+    "StyleOptionSlider",
+    "StyleOptionFrame",
+    "Frame",
+    "ListWidgetItem",
+    "TreeWidgetItem",
+    "Action",
+    "WidgetAction",
+    "ToolButton",
+    "ToolTip",
+    "Menu",
+    "MenuBar",
+    "StatusBar",
+    "TabWidget",
+    "TabBar",
+    "ToolBar",
+    "HeaderView",
+    "DockWidget",
+    "Label",
+    "PushButton",
+    "CommandLinkButton",
+    "RadioButton",
+    "ComboBox",
+    "SpinBox",
+    "DoubleSpinBox",
+    "CheckBox",
+    "LineEdit",
+    "KeySequenceEdit",
+    "TextEdit",
+    "DateEdit",
+    "TimeEdit",
+    "DateTimeEdit",
+    "CalendarWidget",
+    "PlainTextEdit",
+    "TextBrowser",
+    "ProgressBar",
+    "ColumnView",
+    "ListView",
+    "ListWidget",
+    "TreeView",
+    "TreeWidget",
+    "TableView",
+    "TableWidgetItem",
+    "TableWidget",
+    "SplashScreen",
+    "ProgressDialog",
+    "FontDialog",
+    "FileDialog",
+    "ColorDialog",
+    "InputDialog",
+    "DialogButtonBox",
+    "ButtonGroup",
+    "GroupBox",
+    "Splitter",
+    "Wizard",
+    "WizardPage",
+    "MainWindow",
+    "AbstractItemDelegate",
+    "ItemDelegate",
+    "StyledItemDelegate",
+]
