@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
 """
-@author: Philipp Temminghoff
 """
 
 import pathlib
@@ -17,7 +16,6 @@ QtWidgets.QApplication.__bases__ = (gui.GuiApplication,)
 
 
 class Application(QtWidgets.QApplication):
-
     def set_icon(self, icon: icons.IconType):
         """set the icon for the menu
 
@@ -32,11 +30,13 @@ class Application(QtWidgets.QApplication):
         translator.load(str(path))
         self.installTranslator(translator)
 
-    def set_metadata(self,
-                     app_name: Optional[str] = None,
-                     app_version: Optional[str] = None,
-                     org_name: Optional[str] = None,
-                     org_domain: Optional[str] = None):
+    def set_metadata(
+        self,
+        app_name: Optional[str] = None,
+        app_version: Optional[str] = None,
+        org_name: Optional[str] = None,
+        org_domain: Optional[str] = None,
+    ):
         if app_name:
             self.setApplicationName(app_name)
         if app_version:
@@ -47,14 +47,15 @@ class Application(QtWidgets.QApplication):
             self.setOrganizationDomain(org_domain)
 
     def about_popup(self, title="About"):
-        text = (f"{self.applicationName()}\n\n"
-                f"{self.organizationName()}\n"
-                f"{self.applicationVersion()}\n"
-                f"{self.organizationDomain()}")
-        popup = widgets.MessageBox(widgets.MessageBox.NoIcon,
-                                   title,
-                                   text,
-                                   buttons=widgets.MessageBox.Ok)
+        text = (
+            f"{self.applicationName()}\n\n"
+            f"{self.organizationName()}\n"
+            f"{self.applicationVersion()}\n"
+            f"{self.organizationDomain()}"
+        )
+        popup = widgets.MessageBox(
+            widgets.MessageBox.NoIcon, title, text, buttons=widgets.MessageBox.Ok
+        )
         popup.set_icon("mdi.information-outline")
         popup.exec_()
 
@@ -86,6 +87,15 @@ class Application(QtWidgets.QApplication):
                 return widget
         return None
 
+    @classmethod
+    def get_widget(cls, name) -> Optional[QtWidgets.QWidget]:
+        # option 2: mainwindow.findChild(QtWidgets.QWidget, index)
+        widget_list = cls.instance().allWidgets()
+        for widget in widget_list:
+            if isinstance(widget, QtWidgets.QWidget) and widget.objectName() == name:
+                return widget
+        return None
+
     @classmethod
     def create_default_app(cls) -> "Application":
         cls.disable_window_help_button()
