@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
 """
-@author: Philipp Temminghoff
 """
 
 from qtpy import QtWidgets
@@ -8,16 +7,18 @@ from qtpy import QtWidgets
 from prettyqt import gui, widgets
 from prettyqt.utils import colors
 
-OPTIONS = dict(show_alpha=QtWidgets.QColorDialog.ShowAlphaChannel,
-               no_buttons=QtWidgets.QColorDialog.NoButtons,
-               no_native=QtWidgets.QColorDialog.DontUseNativeDialog)
+
+OPTIONS = dict(
+    show_alpha=QtWidgets.QColorDialog.ShowAlphaChannel,
+    no_buttons=QtWidgets.QColorDialog.NoButtons,
+    no_native=QtWidgets.QColorDialog.DontUseNativeDialog,
+)
 
 
 QtWidgets.QColorDialog.__bases__ = (widgets.BaseDialog,)
 
 
 class ColorDialog(QtWidgets.QColorDialog):
-
     def __getstate__(self):
         return dict(color=self.current_color())
 
@@ -27,10 +28,9 @@ class ColorDialog(QtWidgets.QColorDialog):
             self.setCurrentColor(state["color"])
 
     @classmethod
-    def get_color(cls,
-                  preset: colors.ColorType = None,
-                  allow_alpha: bool = False,
-                  parent=None) -> gui.Color:
+    def get_color(
+        cls, preset: colors.ColorType = None, allow_alpha: bool = False, parent=None
+    ) -> gui.Color:
         preset = colors.get_color(preset)
         kwargs = dict(options=cls.ShowAlphaChannel) if allow_alpha else dict()
         return gui.Color(cls.getColor(preset, parent, **kwargs))
