@@ -1,11 +1,10 @@
 # -*- coding: utf-8 -*-
 """
-@author: Philipp Temminghoff
 """
 
 from qtpy import QtWidgets
 
-from prettyqt import widgets, core
+from prettyqt import core, widgets
 
 
 QtWidgets.QCommandLinkButton.__bases__ = (widgets.PushButton,)
