@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
 """
-@author: Philipp Temminghoff
 """
 
 
@@ -9,11 +8,14 @@ from qtpy import QtCore, QtWidgets
 from prettyqt import widgets
 from prettyqt.utils import bidict
 
-ALLOWED_AREAS = bidict(all=QtCore.Qt.AllDockWidgetAreas,
-                       left=QtCore.Qt.LeftDockWidgetArea,
-                       right=QtCore.Qt.RightDockWidgetArea,
-                       top=QtCore.Qt.TopDockWidgetArea,
-                       bottom=QtCore.Qt.BottomDockWidgetArea)
+
+ALLOWED_AREAS = bidict(
+    all=QtCore.Qt.AllDockWidgetAreas,
+    left=QtCore.Qt.LeftDockWidgetArea,
+    right=QtCore.Qt.RightDockWidgetArea,
+    top=QtCore.Qt.TopDockWidgetArea,
+    bottom=QtCore.Qt.BottomDockWidgetArea,
+)
 
 
 QtWidgets.QDockWidget.__bases__ = (widgets.Widget,)
@@ -30,9 +32,9 @@ class DockWidget(QtWidgets.QDockWidget):
         title = kwargs.pop("title", None)
         super().__init__(*args, **kwargs)
         if name:
-            self.id = name
+            self.set_id(name)
         if title:
-            self.title = title
+            self.set_title(title)
         self.set_allowed_areas("all")
 
     def set_widget(self, widget):
