@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
 """
-@author: Philipp Temminghoff
 """
 
 import functools
@@ -9,51 +8,65 @@ from typing import Iterable, Optional
 from qtpy import QtCore, QtWidgets
 
 from prettyqt import core, widgets
-from prettyqt.utils import bidict
+from prettyqt.utils import bidict, helpers
+
+
+ORIENTATIONS = bidict(horizontal=QtCore.Qt.Horizontal, vertical=QtCore.Qt.Vertical)
+
+MODES = bidict(
+    interactive=QtWidgets.QHeaderView.Interactive,
+    fixed=QtWidgets.QHeaderView.Fixed,
+    stretch=QtWidgets.QHeaderView.Stretch,
+    resize_to_contents=QtWidgets.QHeaderView.ResizeToContents,
+)
+
 
 QtWidgets.QHeaderView.__bases__ = (widgets.AbstractItemView,)
 
 
 class HeaderView(QtWidgets.QHeaderView):
-    MODES = bidict(interactive=QtWidgets.QHeaderView.Interactive,
-                   fixed=QtWidgets.QHeaderView.Fixed,
-                   stretch=QtWidgets.QHeaderView.Stretch,
-                   resize_to_contents=QtWidgets.QHeaderView.ResizeToContents)
 
     section_vis_changed = QtCore.Signal(int, bool)
 
-    def __init__(self, orientation=None, parent=None):
-        o = QtCore.Qt.Vertical if orientation == "vertical" else QtCore.Qt.Horizontal
-        super().__init__(o, parent=parent)
+    def __init__(self, orientation, parent=None):
+        if orientation in ORIENTATIONS:
+            orientation = ORIENTATIONS[orientation]
+        super().__init__(orientation, parent=parent)
         self.setSectionsMovable(True)
         self.setSectionsClickable(True)
-        self.widget_name = parent.id
+        self._widget_name = parent.id if parent is not None else ""
 
     def save_state(self):
         settings = core.Settings()
-        settings.setValue(f"{self.widget_name}.state", self.saveState())
+        settings.setValue(f"{self._widget_name}.state", self.saveState())
 
     def load_state(self):
         settings = core.Settings()
-        state = settings.value(f"{self.widget_name}.state", None)
+        state = settings.value(f"{self._widget_name}.state", None)
         if state is not None:
             self.restoreState(state)
 
     def resize_sections(self, mode: str):
-        self.resizeSections(self.MODES[mode])
+        self.resizeSections(MODES[mode])
 
+    @helpers.deprecated
     def resize_mode(self, mode: str, col: Optional[int] = None):
-        if mode not in self.MODES:
+        self.set_resize_mode(mode, col)
+
+    def set_resize_mode(self, mode: str, col: Optional[int] = None):
+        if mode not in MODES:
             raise ValueError("mode not existing")
         if col is None:
-            self.setSectionResizeMode(self.MODES[mode])
+            self.setSectionResizeMode(MODES[mode])
         else:
-            self.setSectionResizeMode(col, self.MODES[mode])
+            self.setSectionResizeMode(col, MODES[mode])
 
     def section_labels(self) -> list:
         model = self.parent().model()
-        return [model.headerData(i, QtCore.Qt.Horizontal, QtCore.Qt.DisplayRole)
-                for i in range(self.count())]
+        return [
+            model.headerData(i, QtCore.Qt.Horizontal, QtCore.Qt.DisplayRole)
+            for i in range(self.count())
+        ]
 
     def contextMenuEvent(self, event):
         """
