@@ -1,47 +1,52 @@
 # -*- coding: utf-8 -*-
 """
-@author: Philipp Temminghoff
 """
 
 import functools
 import operator
 import pathlib
-from typing import Optional, Union
+from typing import List, Optional, Union
 
 from qtpy import QtCore, QtWidgets
 
 from prettyqt import gui, widgets
 from prettyqt.utils import bidict
 
-H_ALIGNMENTS = bidict(left=QtCore.Qt.AlignLeft,
-                      right=QtCore.Qt.AlignRight,
-                      center=QtCore.Qt.AlignHCenter,
-                      justify=QtCore.Qt.AlignJustify)
 
-V_ALIGNMENTS = bidict(top=QtCore.Qt.AlignTop,
-                      bottom=QtCore.Qt.AlignBottom,
-                      center=QtCore.Qt.AlignVCenter,
-                      baseline=QtCore.Qt.AlignBaseline)
+H_ALIGNMENTS = bidict(
+    left=QtCore.Qt.AlignLeft,
+    right=QtCore.Qt.AlignRight,
+    center=QtCore.Qt.AlignHCenter,
+    justify=QtCore.Qt.AlignJustify,
+)
 
-TEXT_INTERACTION = bidict(none=QtCore.Qt.NoTextInteraction,
-                          by_mouse=QtCore.Qt.TextSelectableByMouse,
-                          by_keyboard=QtCore.Qt.TextSelectableByKeyboard,
-                          accessible_by_mouse=QtCore.Qt.LinksAccessibleByMouse,
-                          accessible_by_keyboard=QtCore.Qt.LinksAccessibleByKeyboard,
-                          text_editable=QtCore.Qt.TextEditable,
-                          like_text_editor=QtCore.Qt.TextEditorInteraction,
-                          like_text_browser=QtCore.Qt.TextBrowserInteraction)
+V_ALIGNMENTS = bidict(
+    top=QtCore.Qt.AlignTop,
+    bottom=QtCore.Qt.AlignBottom,
+    center=QtCore.Qt.AlignVCenter,
+    baseline=QtCore.Qt.AlignBaseline,
+)
 
-TEXT_FORMATS = bidict(rich=QtCore.Qt.RichText,
-                      plain=QtCore.Qt.PlainText,
-                      auto=QtCore.Qt.AutoText)
+TEXT_INTERACTION = bidict(
+    none=QtCore.Qt.NoTextInteraction,
+    by_mouse=QtCore.Qt.TextSelectableByMouse,
+    by_keyboard=QtCore.Qt.TextSelectableByKeyboard,
+    accessible_by_mouse=QtCore.Qt.LinksAccessibleByMouse,
+    accessible_by_keyboard=QtCore.Qt.LinksAccessibleByKeyboard,
+    text_editable=QtCore.Qt.TextEditable,
+    like_text_editor=QtCore.Qt.TextEditorInteraction,
+    like_text_browser=QtCore.Qt.TextBrowserInteraction,
+)
+
+TEXT_FORMATS = bidict(
+    rich=QtCore.Qt.RichText, plain=QtCore.Qt.PlainText, auto=QtCore.Qt.AutoText
+)
 
 
 QtWidgets.QLabel.__bases__ = (widgets.Frame,)
 
 
 class Label(QtWidgets.QLabel):
-
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.openExternalLinks()
@@ -50,15 +55,17 @@ class Label(QtWidgets.QLabel):
         return f"Label({self.text()!r})"
 
     def __getstate__(self):
-        return dict(text=self.text(),
-                    scaled_contents=self.hasScaledContents(),
-                    indent=self.indent(),
-                    margin=self.margin(),
-                    text_format=self.get_text_format(),
-                    # pixmap=self.pixmap(),
-                    open_external_links=self.openExternalLinks(),
-                    alignment=int(self.alignment()),
-                    word_wrap=self.wordWrap())
+        return dict(
+            text=self.text(),
+            scaled_contents=self.hasScaledContents(),
+            indent=self.indent(),
+            margin=self.margin(),
+            text_format=self.get_text_format(),
+            # pixmap=self.pixmap(),
+            open_external_links=self.openExternalLinks(),
+            alignment=int(self.alignment()),
+            word_wrap=self.wordWrap(),
+        )
 
     def __setstate__(self, state):
         self.__init__()
@@ -79,9 +86,9 @@ class Label(QtWidgets.QLabel):
         self.setTextInteractionFlags(QtCore.Qt.TextBrowserInteraction)
         self.setOpenExternalLinks(True)
 
-    def set_alignment(self,
-                      horizontal: Optional[str] = None,
-                      vertical: Optional[str] = None):
+    def set_alignment(
+        self, horizontal: Optional[str] = None, vertical: Optional[str] = None
+    ):
         if horizontal is None and vertical is not None:
             flag = V_ALIGNMENTS.get(vertical)
         elif vertical is None and horizontal is not None:
@@ -134,7 +141,7 @@ class Label(QtWidgets.QLabel):
         flags = functools.reduce(operator.ior, [TEXT_INTERACTION[t] for t in types])
         self.setTextInteractionFlags(flags)
 
-    def get_text_interaction(self) -> str:
+    def get_text_interaction(self) -> List[str]:
         """returns current text interaction mode
 
         Possible values: "none", "by_mouse", "by_keyboard", "text_editable"
@@ -147,19 +154,17 @@ class Label(QtWidgets.QLabel):
     def set_text(self, text: str):
         self.setText(text)
 
-    def set_image(self,
-                  path: Union[pathlib.Path, str],
-                  width: int = 300):
+    def set_image(self, path: Union[pathlib.Path, str], width: int = 300):
         self.setScaledContents(True)
         self.set_alignment(horizontal="center")
-        self.setText("<html><head/><body><p>"
-                     f"<img src={str(path)!r} width={str(width)!r}/>"
-                     "</p></body></html>")
+        self.setText(
+            "<html><head/><body><p>"
+            f"<img src={str(path)!r} width={str(width)!r}/>"
+            "</p></body></html>"
+        )
 
     @classmethod
-    def image_from_path(cls,
-                        path: Union[pathlib.Path, str],
-                        parent=None) -> "Label":
+    def image_from_path(cls, path: Union[pathlib.Path, str], parent=None) -> "Label":
         pixmap = gui.Pixmap.from_file(path)
         label = cls(parent=parent)
         label.setPixmap(pixmap)
