@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
 """
-@author: Philipp Temminghoff
 """
 
 from qtpy import QtCore, QtWidgets
@@ -8,24 +7,28 @@ from qtpy import QtCore, QtWidgets
 from prettyqt import core, widgets
 from prettyqt.utils import bidict
 
-MODES = bidict(default=QtWidgets.QLayout.SetDefaultConstraint,
-               fixed=QtWidgets.QLayout.SetFixedSize,
-               minimum=QtWidgets.QLayout.SetMinimumSize,
-               maximum=QtWidgets.QLayout.SetMaximumSize,
-               min_and_max=QtWidgets.QLayout.SetMinAndMaxSize,
-               none=QtWidgets.QLayout.SetNoConstraint)
 
-ALIGNMENTS = bidict(left=QtCore.Qt.AlignLeft,
-                    right=QtCore.Qt.AlignRight,
-                    top=QtCore.Qt.AlignTop,
-                    bottom=QtCore.Qt.AlignBottom)
+MODES = bidict(
+    default=QtWidgets.QLayout.SetDefaultConstraint,
+    fixed=QtWidgets.QLayout.SetFixedSize,
+    minimum=QtWidgets.QLayout.SetMinimumSize,
+    maximum=QtWidgets.QLayout.SetMaximumSize,
+    min_and_max=QtWidgets.QLayout.SetMinAndMaxSize,
+    none=QtWidgets.QLayout.SetNoConstraint,
+)
+
+ALIGNMENTS = bidict(
+    left=QtCore.Qt.AlignLeft,
+    right=QtCore.Qt.AlignRight,
+    top=QtCore.Qt.AlignTop,
+    bottom=QtCore.Qt.AlignBottom,
+)
 
 
 QtWidgets.QLayout.__bases__ = (core.Object, widgets.LayoutItem)
 
 
 class Layout(QtWidgets.QLayout):
-
     def __getitem__(self, index):
         item = self.itemAt(index)
         widget = item.widget()
@@ -45,7 +48,7 @@ class Layout(QtWidgets.QLayout):
     def __contains__(self, item):
         return item in self.get_children()
 
-    def get_children(self):
+    def get_children(self) -> list:
         return list(self)
 
     def set_margin(self, margin: int):
