@@ -1,18 +1,19 @@
 # -*- coding: utf-8 -*-
 """
-@author: Philipp Temminghoff
 """
 
-from qtpy import QtWidgets, QtCore
+from qtpy import QtCore, QtWidgets
 
-from prettyqt import widgets, core
+from prettyqt import core, widgets
 from prettyqt.utils import bidict, icons
 
 
-SCROLL_HINTS = bidict(ensure_visible=QtWidgets.QAbstractItemView.EnsureVisible,
-                      position_at_top=QtWidgets.QAbstractItemView.PositionAtTop,
-                      position_at_bottom=QtWidgets.QAbstractItemView.PositionAtBottom,
-                      position_at_center=QtWidgets.QAbstractItemView.PositionAtCenter)
+SCROLL_HINTS = bidict(
+    ensure_visible=QtWidgets.QAbstractItemView.EnsureVisible,
+    position_at_top=QtWidgets.QAbstractItemView.PositionAtTop,
+    position_at_bottom=QtWidgets.QAbstractItemView.PositionAtBottom,
+    position_at_center=QtWidgets.QAbstractItemView.PositionAtCenter,
+)
 
 
 QtWidgets.QListWidget.__bases__ = (widgets.ListView,)
@@ -49,10 +50,12 @@ class ListWidget(QtWidgets.QListWidget):
         return self.count()
 
     def __getstate__(self):
-        return dict(items=self.get_children(),
-                    selection_mode=self.get_selection_mode(),
-                    sorting_enabled=self.isSortingEnabled(),
-                    current_row=self.currentRow())
+        return dict(
+            items=self.get_children(),
+            selection_mode=self.get_selection_mode(),
+            sorting_enabled=self.isSortingEnabled(),
+            current_row=self.currentRow(),
+        )
 
     def __setstate__(self, state):
         self.__init__()
@@ -70,7 +73,7 @@ class ListWidget(QtWidgets.QListWidget):
         data = self.get_value()
         self.value_changed.emit(data)
 
-    def get_children(self):
+    def get_children(self) -> list:
         return [self.item(index) for index in range(self.count())]
 
     def add_items(self, items):
@@ -80,10 +83,7 @@ class ListWidget(QtWidgets.QListWidget):
             else:
                 self.add(i)
 
-    def add(self,
-            label: str,
-            data=NoData,
-            icon: icons.IconType = None):
+    def add(self, label: str, data=NoData, icon: icons.IconType = None):
         if data is NoData:
             data = label
         item = widgets.ListWidgetItem(label)
