@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
 """
-@author: Philipp Temminghoff
 """
 
 import logging
@@ -10,17 +9,22 @@ from qtpy import QtCore, QtWidgets
 from prettyqt import core, gui, widgets
 from prettyqt.utils import bidict, icons
 
-DOCK_POSITIONS = bidict(top=QtCore.Qt.TopDockWidgetArea,
-                        bottom=QtCore.Qt.BottomDockWidgetArea,
-                        left=QtCore.Qt.LeftDockWidgetArea,
-                        right=QtCore.Qt.RightDockWidgetArea)
 
-TOOLBAR_AREAS = bidict(left=QtCore.Qt.LeftToolBarArea,
-                       right=QtCore.Qt.RightToolBarArea,
-                       top=QtCore.Qt.TopToolBarArea,
-                       bottom=QtCore.Qt.BottomToolBarArea,
-                       all=QtCore.Qt.AllToolBarAreas,
-                       none=QtCore.Qt.NoToolBarArea)
+DOCK_POSITIONS = bidict(
+    top=QtCore.Qt.TopDockWidgetArea,
+    bottom=QtCore.Qt.BottomDockWidgetArea,
+    left=QtCore.Qt.LeftDockWidgetArea,
+    right=QtCore.Qt.RightDockWidgetArea,
+)
+
+TOOLBAR_AREAS = bidict(
+    left=QtCore.Qt.LeftToolBarArea,
+    right=QtCore.Qt.RightToolBarArea,
+    top=QtCore.Qt.TopToolBarArea,
+    bottom=QtCore.Qt.BottomToolBarArea,
+    all=QtCore.Qt.AllToolBarAreas,
+    none=QtCore.Qt.NoToolBarArea,
+)
 
 
 QtWidgets.QMainWindow.__bases__ = (widgets.Widget,)
@@ -34,25 +38,29 @@ class MainWindow(QtWidgets.QMainWindow):
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
-        self.setDockOptions(self.AllowTabbedDocks |
-                            self.AllowNestedDocks |
-                            self.GroupedDragging |
-                            self.AnimatedDocks)
+        self.setDockOptions(
+            self.AllowTabbedDocks
+            | self.AllowNestedDocks
+            | self.GroupedDragging
+            | self.AnimatedDocks
+        )
 
     def __getitem__(self, index):
         return self.findChild(QtWidgets.QWidget, index)
 
     def __getstate__(self):
         icon = gui.Icon(self.windowIcon())
-        return dict(central_widget=self.centralWidget(),
-                    title=self.windowTitle(),
-                    is_maximized=self.isMaximized(),
-                    icon=icon if not icon.isNull() else None,
-                    size=(self.size().width(), self.size().height()))
+        return dict(
+            central_widget=self.centralWidget(),
+            title=self.windowTitle(),
+            is_maximized=self.isMaximized(),
+            icon=icon if not icon.isNull() else None,
+            size=(self.size().width(), self.size().height()),
+        )
 
     def __setstate__(self, state):
         self.__init__()
-        self.title = state["title"]
+        self.set_title(state["title"])
         self.set_icon(state["icon"])
         if state["central_widget"]:
             self.setCentralWidget(state["central_widget"])
@@ -117,27 +125,37 @@ class MainWindow(QtWidgets.QMainWindow):
             raise ValueError("Position not existing")
         self.addToolBarBreak(TOOLBAR_AREAS[position])
 
-    def load_window_state(self):
+    def load_window_state(self, recursive=False):
         settings = core.Settings()
-        geom = settings.value("mainwindow.geometry", None)
-        state = settings.value("mainwindow.state", None)
+        name = self.get_id()
+        geom = settings.get(f"{name}.geometry")
+        state = settings.get(f"{name}.state")
         if geom is not None and state is not None:
             try:
+                logging.debug(f"Loading window state for {name}...")
                 self.restoreGeometry(geom)
                 self.restoreState(state)
             except TypeError:
-                logging.info("Wrong type for window state. Probably Qt binding switch?")
+                logging.error("Wrong type for window state. Probably Qt binding switch?")
+        if recursive:
+            for window in self.find_children(MainWindow, recursive=True):
+                if window.get_id():
+                    window.load_window_state()
 
-    def closeEvent(self, event):
+    def save_window_state(self, recursive=False):
         """
         override, gets executed when app gets closed.
         saves GUI settings
         """
         settings = core.Settings()
-        settings.set_value("mainwindow.geometry", self.saveGeometry())
-        settings.set_value("mainwindow.state", self.saveState())
-        super().closeEvent(event)
-        event.accept()
+        name = self.get_id()
+        logging.debug(f"Saving window state for {name}...")
+        settings[f"{name}.geometry"] = self.saveGeometry()
+        settings[f"{name}.state"] = self.saveState()
+        if recursive:
+            for window in self.find_children(MainWindow, recursive=True):
+                if window.get_id():
+                    window.save_window_state()
 
     def set_icon(self, icon: icons.IconType):
         """set the icon for the menu
@@ -148,14 +166,12 @@ class MainWindow(QtWidgets.QMainWindow):
         icon = icons.get_icon(icon, color="lightgray")
         self.setWindowIcon(icon)
 
-    def add_widget_as_dock(self,
-                           name: str,
-                           title: str,
-                           vertical: bool = True,
-                           position: str = "left") -> widgets.DockWidget:
+    def add_widget_as_dock(
+        self, name: str, title: str, vertical: bool = True, position: str = "left"
+    ) -> widgets.DockWidget:
         dock_widget = widgets.DockWidget(self, name=name, title=title)
         widget = widgets.Widget()
-        widget.id = f"{name}.widget"
+        widget.set_id(f"{name}.widget")
         orientation = "vertical" if vertical else "horizontal"
         layout = widgets.BoxLayout(orientation, widget, margin=0)
         dock_widget.setWidget(widget)
