@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
 """
-@author: Philipp Temminghoff
 """
 
 from typing import Any, Callable, Optional, Union
@@ -10,11 +9,11 @@ from qtpy import QtWidgets
 from prettyqt import core, widgets
 from prettyqt.utils import icons
 
+
 QtWidgets.QMenu.__bases__ = (widgets.Widget,)
 
 
 class Menu(QtWidgets.QMenu):
-
     def __init__(self, title: str = "", icon: icons.IconType = None, parent=None):
         super().__init__(title, parent=parent)
         self.set_icon(icon)
@@ -73,25 +72,26 @@ class Menu(QtWidgets.QMenu):
         self.add(separator)
         return separator
 
-    def add_action(self,
-                   label: Union[str, widgets.Action],
-                   callback: Callable = None,
-                   icon: Optional[Any] = None,
-                   checkable: bool = False,
-                   checked: bool = False,
-                   shortcut: Optional[str] = None,
-                   status_tip: Optional[str] = None
-                   ) -> widgets.Action:
+    def add_action(
+        self,
+        label: Union[str, widgets.Action],
+        callback: Callable = None,
+        icon: Optional[Any] = None,
+        checkable: bool = False,
+        checked: bool = False,
+        shortcut: Optional[str] = None,
+        status_tip: Optional[str] = None,
+    ) -> widgets.Action:
         """Add an action to the menu
 
         Args:
             label: Label for button
             callback: gets called when action is triggered
-            icon: icon for button (default: {None})
-            checkable: as checkbox button (default: {False})
-            checked: if checkable, turn on by default (default: {False})
-            shortcut: Shortcut for action (a) (default: {None})
-            status_tip: Status tip to be shown in status bar (default: {None})
+            icon: icon for button
+            checkable: as checkbox button
+            checked: if checkable, turn on by default
+            shortcut: Shortcut for action
+            status_tip: Status tip to be shown in status bar
 
         Returns:
             Action added to menu
