@@ -1,59 +1,70 @@
 # -*- coding: utf-8 -*-
 """
-@author: Philipp Temminghoff
 """
 
-from qtpy import QtWidgets, QtCore
+from typing import Optional
+
+from qtpy import QtCore, QtWidgets
 
 from prettyqt import widgets
 from prettyqt.utils import bidict, icons
 
 
-ICONS = bidict(none=QtWidgets.QMessageBox.NoIcon,
-               information=QtWidgets.QMessageBox.Information,
-               warning=QtWidgets.QMessageBox.Warning,
-               critical=QtWidgets.QMessageBox.Critical,
-               question=QtWidgets.QMessageBox.Question)
+ICONS = bidict(
+    none=QtWidgets.QMessageBox.NoIcon,
+    information=QtWidgets.QMessageBox.Information,
+    warning=QtWidgets.QMessageBox.Warning,
+    critical=QtWidgets.QMessageBox.Critical,
+    question=QtWidgets.QMessageBox.Question,
+)
 
-BUTTONS = bidict(none=QtWidgets.QMessageBox.NoButton,
-                 cancel=QtWidgets.QMessageBox.Cancel,
-                 ok=QtWidgets.QMessageBox.Ok,
-                 save=QtWidgets.QMessageBox.Save,
-                 open=QtWidgets.QMessageBox.Open,
-                 close=QtWidgets.QMessageBox.Close,
-                 discard=QtWidgets.QMessageBox.Discard,
-                 apply=QtWidgets.QMessageBox.Apply,
-                 reset=QtWidgets.QMessageBox.Reset,
-                 restore_defaults=QtWidgets.QMessageBox.RestoreDefaults,
-                 help=QtWidgets.QMessageBox.Help,
-                 save_all=QtWidgets.QMessageBox.SaveAll,
-                 yes=QtWidgets.QMessageBox.Yes,
-                 yes_to_all=QtWidgets.QMessageBox.YesToAll,
-                 no=QtWidgets.QMessageBox.No,
-                 no_to_all=QtWidgets.QMessageBox.NoToAll,
-                 abort=QtWidgets.QMessageBox.Abort,
-                 retry=QtWidgets.QMessageBox.Retry,
-                 ignore=QtWidgets.QMessageBox.Ignore)
+BUTTONS = bidict(
+    none=QtWidgets.QMessageBox.NoButton,
+    cancel=QtWidgets.QMessageBox.Cancel,
+    ok=QtWidgets.QMessageBox.Ok,
+    save=QtWidgets.QMessageBox.Save,
+    open=QtWidgets.QMessageBox.Open,
+    close=QtWidgets.QMessageBox.Close,
+    discard=QtWidgets.QMessageBox.Discard,
+    apply=QtWidgets.QMessageBox.Apply,
+    reset=QtWidgets.QMessageBox.Reset,
+    restore_defaults=QtWidgets.QMessageBox.RestoreDefaults,
+    help=QtWidgets.QMessageBox.Help,
+    save_all=QtWidgets.QMessageBox.SaveAll,
+    yes=QtWidgets.QMessageBox.Yes,
+    yes_to_all=QtWidgets.QMessageBox.YesToAll,
+    no=QtWidgets.QMessageBox.No,
+    no_to_all=QtWidgets.QMessageBox.NoToAll,
+    abort=QtWidgets.QMessageBox.Abort,
+    retry=QtWidgets.QMessageBox.Retry,
+    ignore=QtWidgets.QMessageBox.Ignore,
+)
 
-TEXT_FORMATS = bidict(rich=QtCore.Qt.RichText,
-                      plain=QtCore.Qt.PlainText,
-                      auto=QtCore.Qt.AutoText)
+TEXT_FORMATS = bidict(
+    rich=QtCore.Qt.RichText, plain=QtCore.Qt.PlainText, auto=QtCore.Qt.AutoText
+)
 
 
 QtWidgets.QMessageBox.__bases__ = (widgets.BaseDialog,)
 
 
 class MessageBox(QtWidgets.QMessageBox):
-
-    def __init__(self, icon=None, title=None, text="", details="", buttons=None,
-                 parent=None):
+    def __init__(
+        self,
+        icon: icons.IconType = None,
+        title: Optional[str] = None,
+        text: str = "",
+        details: str = "",
+        buttons: Optional[list] = None,
+        parent=None,
+    ):
         super().__init__(parent)
         self.set_icon(icon)
         self.setText(text)
         self.setWindowTitle(title)
-        self.setWindowFlags(QtCore.Qt.Dialog |
-                            QtCore.Qt.WindowTitleHint |
-                            QtCore.Qt.CustomizeWindowHint)
+        self.setWindowFlags(
+            QtCore.Qt.Dialog | QtCore.Qt.WindowTitleHint | QtCore.Qt.CustomizeWindowHint
+        )
         self.setDetailedText(details)
         if isinstance(buttons, list):
             for b in buttons:
@@ -61,7 +72,7 @@ class MessageBox(QtWidgets.QMessageBox):
 
     @classmethod
     def message(cls, text: str, title: str = None, icon: icons.IconType = None):
-        m = cls(cls.NoIcon, title, text)
+        m = cls("none", title, text)
         m.set_icon(icon)
         return m.show_blocking()
 
@@ -69,7 +80,8 @@ class MessageBox(QtWidgets.QMessageBox):
         if icon in ICONS:
             self.setIcon(ICONS[icon])
             return None
-        super().set_icon(icon)
+        icon = icons.get_icon(icon)
+        self.setIconPixmap(icon.get_pixmap(size=64))
 
     def show_blocking(self):
         return BUTTONS.inv[self.exec_()]
@@ -133,6 +145,7 @@ class MessageBox(QtWidgets.QMessageBox):
 if __name__ == "__main__":
     app = widgets.app()
     ret = MessageBox(icon="warning", title="header", text="text", details="details")
+    ret.set_icon("mdi.folder")
     ret.show()
     print(ret)
     app.exec_()
