@@ -1,12 +1,12 @@
 # -*- coding: utf-8 -*-
 """
-@author: Philipp Temminghoff
 """
 
 from qtpy import QtWidgets
 
 from prettyqt import core, widgets
 
+
 QtWidgets.QSpinBox.__bases__ = (widgets.AbstractSpinBox,)
 
 
@@ -22,18 +22,20 @@ class SpinBox(QtWidgets.QSpinBox):
             self.set_value(default_value)
 
     def __getstate__(self):
-        return dict(range=(self.minimum(), self.maximum()),
-                    value=self.value(),
-                    enabled=self.isEnabled(),
-                    tooltip=self.toolTip(),
-                    statustip=self.statusTip(),
-                    prefix=self.prefix(),
-                    suffix=self.suffix(),
-                    int_base=self.displayIntegerBase(),
-                    step_type=self.get_step_type(),
-                    button_symbols=self.get_button_symbols(),
-                    correction_mode=self.get_correction_mode(),
-                    single_step=self.singleStep())
+        return dict(
+            range=(self.minimum(), self.maximum()),
+            value=self.value(),
+            enabled=self.isEnabled(),
+            tooltip=self.toolTip(),
+            statustip=self.statusTip(),
+            prefix=self.prefix(),
+            suffix=self.suffix(),
+            int_base=self.displayIntegerBase(),
+            step_type=self.get_step_type(),
+            button_symbols=self.get_button_symbols(),
+            correction_mode=self.get_correction_mode(),
+            single_step=self.singleStep(),
+        )
 
     def __setstate__(self, state):
         self.__init__()
