@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
 """
-@author: Philipp Temminghoff
 """
 
 from qtpy import QtCore, QtGui, QtWidgets
@@ -9,26 +8,31 @@ from prettyqt import widgets
 from prettyqt.utils import bidict
 
 
-ELIDE_MODES = bidict(left=QtCore.Qt.ElideLeft,
-                     right=QtCore.Qt.ElideRight,
-                     middle=QtCore.Qt.ElideMiddle,
-                     none=QtCore.Qt.ElideNone)
+ELIDE_MODES = bidict(
+    left=QtCore.Qt.ElideLeft,
+    right=QtCore.Qt.ElideRight,
+    middle=QtCore.Qt.ElideMiddle,
+    none=QtCore.Qt.ElideNone,
+)
 
-REMOVE_BEHAVIOURS = bidict(left_tab=QtWidgets.QTabBar.SelectLeftTab,
-                           right_tab=QtWidgets.QTabBar.SelectRightTab,
-                           previous_tab=QtWidgets.QTabBar.SelectPreviousTab)
+REMOVE_BEHAVIOURS = bidict(
+    left_tab=QtWidgets.QTabBar.SelectLeftTab,
+    right_tab=QtWidgets.QTabBar.SelectRightTab,
+    previous_tab=QtWidgets.QTabBar.SelectPreviousTab,
+)
 
-SHAPES = bidict(rounded_north=QtWidgets.QTabBar.RoundedNorth,
-                rounded_south=QtWidgets.QTabBar.RoundedSouth,
-                rounded_west=QtWidgets.QTabBar.RoundedWest,
-                rounded_east=QtWidgets.QTabBar.RoundedEast,
-                triangular_north=QtWidgets.QTabBar.TriangularNorth,
-                triangular_south=QtWidgets.QTabBar.TriangularSouth,
-                triangular_west=QtWidgets.QTabBar.TriangularWest,
-                triangular_east=QtWidgets.QTabBar.TriangularEast)
+SHAPES = bidict(
+    rounded_north=QtWidgets.QTabBar.RoundedNorth,
+    rounded_south=QtWidgets.QTabBar.RoundedSouth,
+    rounded_west=QtWidgets.QTabBar.RoundedWest,
+    rounded_east=QtWidgets.QTabBar.RoundedEast,
+    triangular_north=QtWidgets.QTabBar.TriangularNorth,
+    triangular_south=QtWidgets.QTabBar.TriangularSouth,
+    triangular_west=QtWidgets.QTabBar.TriangularWest,
+    triangular_east=QtWidgets.QTabBar.TriangularEast,
+)
 
-POSITIONS = bidict(left=QtWidgets.QTabBar.LeftSide,
-                   right=QtWidgets.QTabBar.RightSide)
+POSITIONS = bidict(left=QtWidgets.QTabBar.LeftSide, right=QtWidgets.QTabBar.RightSide)
 
 
 QtWidgets.QTabBar.__bases__ = (widgets.Widget,)
@@ -52,13 +56,15 @@ class TabBar(QtWidgets.QTabBar):
         self.set_tab(index[0], index[1], value)
 
     def __getstate__(self):
-        return dict(movable=self.isMovable(),
-                    document_mode=self.documentMode(),
-                    current_index=self.currentIndex(),
-                    # shape=self.shape(),
-                    draw_base=self.drawBase(),
-                    elide_mode=self.get_elide_mode(),
-                    icon_size=self.iconSize())
+        return dict(
+            movable=self.isMovable(),
+            document_mode=self.documentMode(),
+            current_index=self.currentIndex(),
+            # shape=self.shape(),
+            draw_base=self.drawBase(),
+            elide_mode=self.get_elide_mode(),
+            icon_size=self.iconSize(),
+        )
 
     def __setstate__(self, state):
         self.__init__()
@@ -76,6 +82,11 @@ class TabBar(QtWidgets.QTabBar):
         self.on_detach.emit(self.tabAt(event.pos()), self.mouse_cursor.pos())
 
     def set_icon_size(self, size: int):
+        """Set the icon size for the tabs
+
+        Args:
+            size: height/width of the icons
+        """
         self.setIconSize(QtCore.QSize(size, size))
 
     def set_tab(self, index: int, position, widget):
