@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
 """
-@author: Philipp Temminghoff
 """
 
 from qtpy import QtWidgets
@@ -12,10 +11,10 @@ QtWidgets.QTableView.__bases__ = (widgets.AbstractItemView,)
 
 
 class TableView(QtWidgets.QTableView):
-
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
-        self.id = self.__class__.__name__
+        class_name = type(self).__name__
+        self.set_id(class_name)
         self.setHorizontalHeader(widgets.HeaderView("horizontal", parent=self))
         self.setVerticalHeader(widgets.HeaderView("vertical", parent=self))
         self.setAlternatingRowColors(True)
@@ -40,7 +39,7 @@ class TableView(QtWidgets.QTableView):
     def setup_list_style(self):
         self.set_selection_behaviour("rows")
         self.h_header.setStretchLastSection(True)
-        self.v_header.resize_mode("fixed")
+        self.v_header.set_resize_mode("fixed")
         self.v_header.set_default_section_size(28)
 
     def adapt_sizes(self):
