@@ -1,14 +1,16 @@
 # -*- coding: utf-8 -*-
 """
-@author: Philipp Temminghoff
 """
 
+import pathlib
+from typing import Union
+
+
 import docutils.core
 from qtpy import QtWidgets
-from typing import Union
-import pathlib
 
-from prettyqt import gui, widgets, core
+from prettyqt import core, gui, widgets
+
 
 QtWidgets.QTextBrowser.__bases__ = (widgets.TextEdit,)
 
@@ -22,9 +24,9 @@ class TextBrowser(QtWidgets.QTextBrowser):
         self.setOpenExternalLinks(True)
 
     def __getstate__(self):
-        return dict(text=self.text(),
-                    enabled=self.isEnabled(),
-                    font=gui.Font(self.font()))
+        return dict(
+            text=self.text(), enabled=self.isEnabled(), font=gui.Font(self.font())
+        )
 
     def __setstate__(self, state):
         self.__init__()
