@@ -1,12 +1,12 @@
 # -*- coding: utf-8 -*-
 """
-@author: Philipp Temminghoff
 """
 
 import datetime
 
 from qtpy import QtWidgets
-from prettyqt import widgets, core
+
+from prettyqt import core, widgets
 
 
 QtWidgets.QTimeEdit.__bases__ = (widgets.DateTimeEdit,)
@@ -17,13 +17,15 @@ class TimeEdit(QtWidgets.QTimeEdit):
     value_changed = core.Signal(datetime.datetime)
 
     def __getstate__(self):
-        return dict(calendar_popup=self.calendarPopup(),
-                    time=self.get_time(),
-                    display_format=self.displayFormat(),
-                    range=(self.min_time(), self.max_time()),
-                    tooltip=self.toolTip(),
-                    statustip=self.statusTip(),
-                    enabled=self.isEnabled())
+        return dict(
+            calendar_popup=self.calendarPopup(),
+            time=self.get_time(),
+            display_format=self.displayFormat(),
+            range=(self.min_time(), self.max_time()),
+            tooltip=self.toolTip(),
+            statustip=self.statusTip(),
+            enabled=self.isEnabled(),
+        )
 
     def __setstate__(self, state):
         self.__init__(state["time"])
@@ -46,6 +48,7 @@ class TimeEdit(QtWidgets.QTimeEdit):
 
 if __name__ == "__main__":
     from prettyqt import widgets
+
     app = widgets.app()
     widget = TimeEdit()
     widget.show()
