@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 """
-@author: Philipp Temminghoff
 """
 
 from typing import Optional
 
 from qtpy import QtWidgets
 
-from prettyqt import widgets, gui
+from prettyqt import gui, widgets
 from prettyqt.utils import icons
 
 
@@ -15,7 +14,6 @@ QtWidgets.QToolBox.__bases__ = (widgets.Frame,)
 
 
 class ToolBox(QtWidgets.QToolBox):
-
     def __getitem__(self, index):
         if isinstance(index, int):
             return self.widget(index)
@@ -25,14 +23,15 @@ class ToolBox(QtWidgets.QToolBox):
     def __getstate__(self):
         children = list()
         for i, widget in enumerate(self.get_children()):
-            dct = dict(widget=widget,
-                       icon=gui.Icon(self.itemIcon(i)),
-                       text=self.itemText(i),
-                       enabled=self.isItemEnabled(i),
-                       tooltip=self.itemToolTip(i))
+            dct = dict(
+                widget=widget,
+                icon=gui.Icon(self.itemIcon(i)),
+                text=self.itemText(i),
+                enabled=self.isItemEnabled(i),
+                tooltip=self.itemToolTip(i),
+            )
             children.append(dct)
-        return dict(items=children,
-                    current_index=self.currentIndex())
+        return dict(items=children, current_index=self.currentIndex())
 
     def __setstate__(self, state):
         self.__init__()
@@ -48,10 +47,9 @@ class ToolBox(QtWidgets.QToolBox):
     def get_children(self) -> list:
         return [self[i] for i in range(self.count())]
 
-    def add_widget(self,
-                   widget,
-                   title: Optional[str] = None,
-                   icon: icons.IconType = None):
+    def add_widget(
+        self, widget, title: Optional[str] = None, icon: icons.IconType = None
+    ):
         if title is None:
             title = widget.id
         if icon:
@@ -65,7 +63,6 @@ if __name__ == "__main__":
     app = widgets.app()
     w = widgets.Widget()
     w2 = widgets.Widget()
-    w2.id = "objectName"
     tb = ToolBox()
     tb.add_widget(w, "title")
     tb.add_widget(w2)
