@@ -1,9 +1,8 @@
 # -*- coding: utf-8 -*-
 """
-@author: Philipp Temminghoff
 """
 
-from qtpy import QtWidgets, QtCore
+from qtpy import QtCore, QtWidgets
 
 from prettyqt import widgets
 
@@ -12,7 +11,6 @@ QtWidgets.QTreeWidget.__bases__ = (widgets.TreeView,)
 
 
 class TreeWidget(QtWidgets.QTreeWidget):
-
     def sort(self, column=0, reverse=False):
         order = QtCore.Qt.DescendingOrder if reverse else QtCore.Qt.AscendingOrder
         self.sortItems(column, order)
