@@ -1,80 +1,91 @@
 # -*- coding: utf-8 -*-
 """
-@author: Philipp Temminghoff
 """
 
 from contextlib import contextmanager
-from typing import Callable, Dict, Optional
-import operator
 import functools
+import operator
+from typing import Callable, Dict, Optional
 
 from qtpy import QtCore, QtGui, QtWidgets
 
 from prettyqt import core, gui, widgets
 from prettyqt.utils import bidict
 
-POLICIES = bidict(none=QtCore.Qt.NoContextMenu,
-                  prevent=QtCore.Qt.PreventContextMenu,
-                  default=QtCore.Qt.DefaultContextMenu,
-                  actions=QtCore.Qt.ActionsContextMenu,
-                  custom=QtCore.Qt.CustomContextMenu,
-                  showhide_menu="showhide_menu")
 
-MODALITIES = bidict(window=QtCore.Qt.WindowModal,
-                    application=QtCore.Qt.ApplicationModal,
-                    none=QtCore.Qt.NonModal)
+POLICIES = bidict(
+    none=QtCore.Qt.NoContextMenu,
+    prevent=QtCore.Qt.PreventContextMenu,
+    default=QtCore.Qt.DefaultContextMenu,
+    actions=QtCore.Qt.ActionsContextMenu,
+    custom=QtCore.Qt.CustomContextMenu,
+    showhide_menu="showhide_menu",
+)
 
-CURSOR_SHAPES = bidict(arrow=QtCore.Qt.ArrowCursor,
-                       uparrow=QtCore.Qt.UpArrowCursor,
-                       cross=QtCore.Qt.CrossCursor,
-                       wait=QtCore.Qt.WaitCursor,
-                       caret=QtCore.Qt.IBeamCursor,
-                       size_vertical=QtCore.Qt.SizeVerCursor,
-                       size_horizonal=QtCore.Qt.SizeHorCursor,
-                       size_topright=QtCore.Qt.SizeBDiagCursor,
-                       size_topleft=QtCore.Qt.SizeFDiagCursor,
-                       size_all=QtCore.Qt.SizeAllCursor,
-                       blank=QtCore.Qt.BlankCursor,
-                       split_vertical=QtCore.Qt.SplitVCursor,
-                       split_horizontal=QtCore.Qt.SplitHCursor,
-                       pointing_hand=QtCore.Qt.PointingHandCursor,
-                       forbidden=QtCore.Qt.ForbiddenCursor,
-                       open_hand=QtCore.Qt.OpenHandCursor,
-                       closed_hand=QtCore.Qt.ClosedHandCursor,
-                       whats_this=QtCore.Qt.WhatsThisCursor,
-                       busy=QtCore.Qt.BusyCursor,
-                       drag_move=QtCore.Qt.DragMoveCursor,
-                       drag_copy=QtCore.Qt.DragCopyCursor,
-                       drag_link=QtCore.Qt.DragLinkCursor,
-                       bitmap=QtCore.Qt.BitmapCursor)
+MODALITIES = bidict(
+    window=QtCore.Qt.WindowModal,
+    application=QtCore.Qt.ApplicationModal,
+    none=QtCore.Qt.NonModal,
+)
 
-FOCUS_POLICIES = bidict(tab=QtCore.Qt.TabFocus,
-                        click=QtCore.Qt.ClickFocus,
-                        strong=QtCore.Qt.StrongFocus,
-                        wheel=QtCore.Qt.WheelFocus,
-                        none=QtCore.Qt.NoFocus)
+CURSOR_SHAPES = bidict(
+    arrow=QtCore.Qt.ArrowCursor,
+    uparrow=QtCore.Qt.UpArrowCursor,
+    cross=QtCore.Qt.CrossCursor,
+    wait=QtCore.Qt.WaitCursor,
+    caret=QtCore.Qt.IBeamCursor,
+    size_vertical=QtCore.Qt.SizeVerCursor,
+    size_horizonal=QtCore.Qt.SizeHorCursor,
+    size_topright=QtCore.Qt.SizeBDiagCursor,
+    size_topleft=QtCore.Qt.SizeFDiagCursor,
+    size_all=QtCore.Qt.SizeAllCursor,
+    blank=QtCore.Qt.BlankCursor,
+    split_vertical=QtCore.Qt.SplitVCursor,
+    split_horizontal=QtCore.Qt.SplitHCursor,
+    pointing_hand=QtCore.Qt.PointingHandCursor,
+    forbidden=QtCore.Qt.ForbiddenCursor,
+    open_hand=QtCore.Qt.OpenHandCursor,
+    closed_hand=QtCore.Qt.ClosedHandCursor,
+    whats_this=QtCore.Qt.WhatsThisCursor,
+    busy=QtCore.Qt.BusyCursor,
+    drag_move=QtCore.Qt.DragMoveCursor,
+    drag_copy=QtCore.Qt.DragCopyCursor,
+    drag_link=QtCore.Qt.DragLinkCursor,
+    bitmap=QtCore.Qt.BitmapCursor,
+)
 
-WINDOW_FLAGS = bidict(frameless=QtCore.Qt.FramelessWindowHint,
-                      popup=QtCore.Qt.Popup,
-                      stay_on_top=QtCore.Qt.WindowStaysOnTopHint,
-                      tool=QtCore.Qt.Tool,
-                      window_title=QtCore.Qt.WindowTitleHint,
-                      customize_window=QtCore.Qt.CustomizeWindowHint)
+FOCUS_POLICIES = bidict(
+    tab=QtCore.Qt.TabFocus,
+    click=QtCore.Qt.ClickFocus,
+    strong=QtCore.Qt.StrongFocus,
+    wheel=QtCore.Qt.WheelFocus,
+    none=QtCore.Qt.NoFocus,
+)
+
+WINDOW_FLAGS = bidict(
+    frameless=QtCore.Qt.FramelessWindowHint,
+    popup=QtCore.Qt.Popup,
+    stay_on_top=QtCore.Qt.WindowStaysOnTopHint,
+    tool=QtCore.Qt.Tool,
+    window_title=QtCore.Qt.WindowTitleHint,
+    customize_window=QtCore.Qt.CustomizeWindowHint,
+)
 
 QtWidgets.QWidget.__bases__ = (core.Object, QtGui.QPaintDevice)
 
 
 class Widget(QtWidgets.QWidget):
-
     def __repr__(self):
         return f"{self.__class__.__name__}: {self.__getstate__()}"
 
     def __getstate__(self):
-        return dict(layout=self.layout(),
-                    size_policy=self.get_size_policy(),
-                    accessible_name=self.accessibleName(),
-                    tooltip=self.toolTip(),
-                    statustip=self.statusTip())
+        return dict(
+            layout=self.layout(),
+            size_policy=self.get_size_policy(),
+            accessible_name=self.accessibleName(),
+            tooltip=self.toolTip(),
+            statustip=self.statusTip(),
+        )
 
     def __setstate__(self, state):
         self.__init__()
@@ -96,16 +107,24 @@ class Widget(QtWidgets.QWidget):
     def set_max_size(self, *size):
         self.setMaximumSize(*size)
 
-    def set_min_width(self, width: int):
+    def set_min_width(self, width: Optional[int]):
+        if width is None:
+            width = 0
         self.setMinimumWidth(width)
 
-    def set_max_width(self, width: int):
+    def set_max_width(self, width: Optional[int]):
+        if width is None:
+            width = QtWidgets.QWIDGETSIZE_MAX
         self.setMaximumWidth(width)
 
-    def set_min_height(self, height: int):
+    def set_min_height(self, height: Optional[int]):
+        if height is None:
+            height = 0
         self.setMinimumHeight(height)
 
-    def set_max_height(self, height: int):
+    def set_max_height(self, height: Optional[int]):
+        if height is None:
+            height = QtWidgets.QWIDGETSIZE_MAX
         self.setMaximumHeight(height)
 
     @property
@@ -136,11 +155,13 @@ class Widget(QtWidgets.QWidget):
     def set_tooltip(self, text: str):
         self.setToolTip(text)
 
-    def set_font(self,
-                 font_name: Optional[str] = None,
-                 font_size: int = -1,
-                 weight: int = -1,
-                 italic: bool = False) -> gui.Font:
+    def set_font(
+        self,
+        font_name: Optional[str] = None,
+        font_size: int = -1,
+        weight: int = -1,
+        italic: bool = False,
+    ) -> gui.Font:
         if font_name is None:
             font_name = self.font().family()
         font = gui.Font(font_name, font_size, weight, italic)
@@ -156,13 +177,15 @@ class Widget(QtWidgets.QWidget):
             flags = flags | self.windowFlags()
         self.setWindowFlags(flags)
 
-    def set_flags(self,
-                  minimize: Optional[bool] = None,
-                  maximize: Optional[bool] = None,
-                  close: Optional[bool] = None,
-                  stay_on_top: Optional[bool] = None,
-                  frameless: Optional[bool] = None,
-                  window: Optional[bool] = None):
+    def set_flags(
+        self,
+        minimize: Optional[bool] = None,
+        maximize: Optional[bool] = None,
+        close: Optional[bool] = None,
+        stay_on_top: Optional[bool] = None,
+        frameless: Optional[bool] = None,
+        window: Optional[bool] = None,
+    ):
         if minimize is not None:
             self.setWindowFlag(QtCore.Qt.WindowMinimizeButtonHint, minimize)
         if maximize is not None:
@@ -182,7 +205,7 @@ class Widget(QtWidgets.QWidget):
         Valid values for modality: "modeless", "window", "application"
 
         Args:
-            modality: modality for the main window (default: {"window"})
+            modality: modality for the main window
 
         Raises:
             ValueError: modality type does not exist
@@ -208,9 +231,9 @@ class Widget(QtWidgets.QWidget):
         yield None
         self.setUpdatesEnabled(True)
 
-    def set_size_policy(self,
-                        horizontal: Optional[str] = None,
-                        vertical: Optional[str] = None):
+    def set_size_policy(
+        self, horizontal: Optional[str] = None, vertical: Optional[str] = None
+    ):
         """sets the sizes policy
 
         possible values for both parameters are "fixed", "minimum", "maximum",
@@ -231,9 +254,9 @@ class Widget(QtWidgets.QWidget):
         qpol = self.sizePolicy()
         if isinstance(qpol, widgets.SizePolicy):
             return qpol
-        pol = widgets.SizePolicy(qpol.horizontalPolicy(),
-                                 qpol.verticalPolicy(),
-                                 qpol.controlType())
+        pol = widgets.SizePolicy(
+            qpol.horizontalPolicy(), qpol.verticalPolicy(), qpol.controlType()
+        )
         pol.setHeightForWidth(qpol.hasHeightForWidth())
         pol.setWidthForHeight(qpol.hasWidthForHeight())
         pol.setHorizontalStretch(qpol.horizontalStretch())
@@ -243,7 +266,7 @@ class Widget(QtWidgets.QWidget):
     def set_background_color(self, color):
         self.setStyleSheet(f"background-color: {color};")
 
-    def set_stylesheet(self, item, dct: Dict[str, str]) -> str:
+    def set_stylesheet(self, item: str, dct: Dict[str, str]) -> str:
         ss = "; ".join(f"{k.replace('_', '-')}: {v}" for k, v in dct.items())
         stylesheet = f"{item} {{{ss};}}"
         self.setStyleSheet(stylesheet)
@@ -291,6 +314,7 @@ class Widget(QtWidgets.QWidget):
             self.box = widgets.StackedLayout()
         elif layout == "flow":
             from prettyqt import custom_widgets
+
             self.box = custom_widgets.FlowLayout()
         else:
             self.box = layout
@@ -315,14 +339,16 @@ class Widget(QtWidgets.QWidget):
 
     def set_cursor(self, cursor: str):
         if cursor not in CURSOR_SHAPES:
-            raise ValueError(f"Invalid cursor '{cursor}'. "
-                             f"Valid values: {CURSOR_SHAPES.keys()}")
+            raise ValueError(
+                f"Invalid cursor '{cursor}'. " f"Valid values: {CURSOR_SHAPES.keys()}"
+            )
         self.setCursor(CURSOR_SHAPES[cursor])
 
     def set_focus_policy(self, policy: str):
         if policy not in FOCUS_POLICIES:
-            raise ValueError(f"Invalid policy '{policy}'. "
-                             f"Valid values: {FOCUS_POLICIES.keys()}")
+            raise ValueError(
+                f"Invalid policy '{policy}'. " f"Valid values: {FOCUS_POLICIES.keys()}"
+            )
         self.setFocusPolicy(FOCUS_POLICIES[policy])
 
     def get_focus_policy(self) -> str:
